@@ -19,7 +19,7 @@ class GenericError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -47,7 +47,7 @@ class BadContextError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -75,7 +75,7 @@ class BadContextStateError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -103,7 +103,7 @@ class BadDrawableError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -131,7 +131,7 @@ class BadPixmapError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -159,7 +159,7 @@ class BadContextTagError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -187,7 +187,7 @@ class BadCurrentWindowError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -215,7 +215,7 @@ class BadRenderRequestError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -243,7 +243,7 @@ class BadLargeRequestError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -271,7 +271,7 @@ class UnsupportedPrivateRequestError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -299,7 +299,7 @@ class BadFBConfigError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -327,7 +327,7 @@ class BadPbufferError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -355,7 +355,7 @@ class BadCurrentDrawableError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -383,7 +383,7 @@ class BadWindowError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -411,7 +411,7 @@ class GLXBadProfileARBError(xcffib.Error):
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
         self.bad_value, self.minor_opcode, self.major_opcode = unpacker.unpack(
-            "xx2xIHB21x"
+            "=xx2xIHB21x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -449,7 +449,7 @@ class PbufferClobberEvent(xcffib.Event):
             self.width,
             self.height,
             self.count,
-        ) = unpacker.unpack("xx2xHHIIHHHHHH4x")
+        ) = unpacker.unpack("=xx2xHHIIHHHHHH4x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -522,7 +522,7 @@ class BufferSwapCompleteEvent(xcffib.Event):
             self.msc_hi,
             self.msc_lo,
             self.sbc,
-        ) = unpacker.unpack("xx2xH2xIIIIII")
+        ) = unpacker.unpack("=xx2xH2xIIIIII")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -579,7 +579,7 @@ class MakeCurrentReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_tag,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_tag,) = unpacker.unpack("=xx2x4xI20x")
         self.bufsize = unpacker.offset - base
 
 
@@ -595,7 +595,7 @@ class IsDirectReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.is_direct,) = unpacker.unpack("xx2x4xB23x")
+        (self.is_direct,) = unpacker.unpack("=xx2x4xB23x")
         self.bufsize = unpacker.offset - base
 
 
@@ -611,7 +611,7 @@ class QueryVersionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major_version, self.minor_version = unpacker.unpack("xx2x4xII16x")
+        self.major_version, self.minor_version = unpacker.unpack("=xx2x4xII16x")
         self.bufsize = unpacker.offset - base
 
 
@@ -651,7 +651,7 @@ class GetVisualConfigsReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.num_visuals, self.num_properties = unpacker.unpack("xx2x4xII16x")
+        self.num_visuals, self.num_properties = unpacker.unpack("=xx2x4xII16x")
         self.property_list = xcffib.List(unpacker, "I", self.length)
         self.bufsize = unpacker.offset - base
 
@@ -668,7 +668,7 @@ class VendorPrivateWithReplyReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.retval,) = unpacker.unpack("xx2x4xI")
+        (self.retval,) = unpacker.unpack("=xx2x4xI")
         self.data1 = xcffib.List(unpacker, "B", 24)
         unpacker.pad("B")
         self.data2 = xcffib.List(unpacker, "B", self.length * 4)
@@ -687,7 +687,7 @@ class QueryExtensionsStringReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.n,) = unpacker.unpack("xx2x4x4xI16x")
+        (self.n,) = unpacker.unpack("=xx2x4x4xI16x")
         self.bufsize = unpacker.offset - base
 
 
@@ -703,7 +703,7 @@ class QueryServerStringReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.str_len,) = unpacker.unpack("xx2x4x4xI16x")
+        (self.str_len,) = unpacker.unpack("=xx2x4x4xI16x")
         self.string = xcffib.List(unpacker, "c", self.str_len)
         self.bufsize = unpacker.offset - base
 
@@ -720,7 +720,7 @@ class GetFBConfigsReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.num_FB_configs, self.num_properties = unpacker.unpack("xx2x4xII16x")
+        self.num_FB_configs, self.num_properties = unpacker.unpack("=xx2x4xII16x")
         self.property_list = xcffib.List(unpacker, "I", self.length)
         self.bufsize = unpacker.offset - base
 
@@ -737,7 +737,7 @@ class QueryContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.num_attribs,) = unpacker.unpack("xx2x4xI20x")
+        (self.num_attribs,) = unpacker.unpack("=xx2x4xI20x")
         self.attribs = xcffib.List(unpacker, "I", self.num_attribs * 2)
         self.bufsize = unpacker.offset - base
 
@@ -754,7 +754,7 @@ class MakeContextCurrentReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context_tag,) = unpacker.unpack("xx2x4xI20x")
+        (self.context_tag,) = unpacker.unpack("=xx2x4xI20x")
         self.bufsize = unpacker.offset - base
 
 
@@ -770,7 +770,7 @@ class GetDrawableAttributesReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.num_attribs,) = unpacker.unpack("xx2x4xI20x")
+        (self.num_attribs,) = unpacker.unpack("=xx2x4xI20x")
         self.attribs = xcffib.List(unpacker, "I", self.num_attribs * 2)
         self.bufsize = unpacker.offset - base
 
@@ -787,7 +787,7 @@ class GenListsReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.ret_val,) = unpacker.unpack("xx2x4xI")
+        (self.ret_val,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -803,7 +803,7 @@ class RenderModeReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.ret_val, self.n, self.new_mode = unpacker.unpack("xx2x4xIII12x")
+        self.ret_val, self.n, self.new_mode = unpacker.unpack("=xx2x4xIII12x")
         self.data = xcffib.List(unpacker, "I", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -826,7 +826,7 @@ class FinishReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x")
+        unpacker.unpack("=xx2x4x")
         self.bufsize = unpacker.offset - base
 
 
@@ -842,7 +842,7 @@ class ReadPixelsReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x24x")
+        unpacker.unpack("=xx2x4x24x")
         self.data = xcffib.List(unpacker, "B", self.length * 4)
         self.bufsize = unpacker.offset - base
 
@@ -859,7 +859,7 @@ class GetBooleanvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIB15x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIB15x")
         self.data = xcffib.List(unpacker, "B", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -876,7 +876,7 @@ class GetErrorReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.error,) = unpacker.unpack("xx2x4xi")
+        (self.error,) = unpacker.unpack("=xx2x4xi")
         self.bufsize = unpacker.offset - base
 
 
@@ -892,7 +892,7 @@ class GetFloatvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -909,7 +909,7 @@ class GetIntegervReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -926,7 +926,7 @@ class GetLightfvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -943,7 +943,7 @@ class GetLightivReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -960,7 +960,7 @@ class GetMapfvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -977,7 +977,7 @@ class GetMapivReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -994,7 +994,7 @@ class GetMaterialfvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1011,7 +1011,7 @@ class GetMaterialivReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1028,7 +1028,7 @@ class GetPixelMapfvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1045,7 +1045,7 @@ class GetPixelMapuivReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xII12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xII12x")
         self.data = xcffib.List(unpacker, "I", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1062,7 +1062,7 @@ class GetPixelMapusvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIH16x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIH16x")
         self.data = xcffib.List(unpacker, "H", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1079,7 +1079,7 @@ class GetPolygonStippleReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x24x")
+        unpacker.unpack("=xx2x4x24x")
         self.data = xcffib.List(unpacker, "B", self.length * 4)
         self.bufsize = unpacker.offset - base
 
@@ -1096,7 +1096,7 @@ class GetStringReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.n,) = unpacker.unpack("xx2x4x4xI16x")
+        (self.n,) = unpacker.unpack("=xx2x4x4xI16x")
         self.string = xcffib.List(unpacker, "c", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1113,7 +1113,7 @@ class GetTexEnvfvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1130,7 +1130,7 @@ class GetTexEnvivReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1147,7 +1147,7 @@ class GetTexGenfvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1164,7 +1164,7 @@ class GetTexGenivReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1181,7 +1181,7 @@ class GetTexImageReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.width, self.height, self.depth = unpacker.unpack("xx2x4x8xiii4x")
+        self.width, self.height, self.depth = unpacker.unpack("=xx2x4x8xiii4x")
         self.data = xcffib.List(unpacker, "B", self.length * 4)
         self.bufsize = unpacker.offset - base
 
@@ -1198,7 +1198,7 @@ class GetTexParameterfvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1215,7 +1215,7 @@ class GetTexParameterivReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1232,7 +1232,7 @@ class GetTexLevelParameterfvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1249,7 +1249,7 @@ class GetTexLevelParameterivReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1266,7 +1266,7 @@ class IsEnabledReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.ret_val,) = unpacker.unpack("xx2x4xI")
+        (self.ret_val,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -1282,7 +1282,7 @@ class IsListReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.ret_val,) = unpacker.unpack("xx2x4xI")
+        (self.ret_val,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -1298,7 +1298,7 @@ class AreTexturesResidentReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.ret_val,) = unpacker.unpack("xx2x4xI20x")
+        (self.ret_val,) = unpacker.unpack("=xx2x4xI20x")
         self.data = xcffib.List(unpacker, "B", self.length * 4)
         self.bufsize = unpacker.offset - base
 
@@ -1315,7 +1315,7 @@ class GenTexturesReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x24x")
+        unpacker.unpack("=xx2x4x24x")
         self.data = xcffib.List(unpacker, "I", self.length)
         self.bufsize = unpacker.offset - base
 
@@ -1332,7 +1332,7 @@ class IsTextureReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.ret_val,) = unpacker.unpack("xx2x4xI")
+        (self.ret_val,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -1348,7 +1348,7 @@ class GetColorTableReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.width,) = unpacker.unpack("xx2x4x8xi12x")
+        (self.width,) = unpacker.unpack("=xx2x4x8xi12x")
         self.data = xcffib.List(unpacker, "B", self.length * 4)
         self.bufsize = unpacker.offset - base
 
@@ -1365,7 +1365,7 @@ class GetColorTableParameterfvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1382,7 +1382,7 @@ class GetColorTableParameterivReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1399,7 +1399,7 @@ class GetConvolutionFilterReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.width, self.height = unpacker.unpack("xx2x4x8xii8x")
+        self.width, self.height = unpacker.unpack("=xx2x4x8xii8x")
         self.data = xcffib.List(unpacker, "B", self.length * 4)
         self.bufsize = unpacker.offset - base
 
@@ -1416,7 +1416,7 @@ class GetConvolutionParameterfvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1433,7 +1433,7 @@ class GetConvolutionParameterivReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1450,7 +1450,7 @@ class GetSeparableFilterReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.row_w, self.col_h = unpacker.unpack("xx2x4x8xii8x")
+        self.row_w, self.col_h = unpacker.unpack("=xx2x4x8xii8x")
         self.rows_and_cols = xcffib.List(unpacker, "B", self.length * 4)
         self.bufsize = unpacker.offset - base
 
@@ -1467,7 +1467,7 @@ class GetHistogramReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.width,) = unpacker.unpack("xx2x4x8xi12x")
+        (self.width,) = unpacker.unpack("=xx2x4x8xi12x")
         self.data = xcffib.List(unpacker, "B", self.length * 4)
         self.bufsize = unpacker.offset - base
 
@@ -1484,7 +1484,7 @@ class GetHistogramParameterfvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1501,7 +1501,7 @@ class GetHistogramParameterivReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1518,7 +1518,7 @@ class GetMinmaxReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x24x")
+        unpacker.unpack("=xx2x4x24x")
         self.data = xcffib.List(unpacker, "B", self.length * 4)
         self.bufsize = unpacker.offset - base
 
@@ -1535,7 +1535,7 @@ class GetMinmaxParameterfvReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIf12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIf12x")
         self.data = xcffib.List(unpacker, "f", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1552,7 +1552,7 @@ class GetMinmaxParameterivReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1569,7 +1569,7 @@ class GetCompressedTexImageARBReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.size,) = unpacker.unpack("xx2x4x8xi12x")
+        (self.size,) = unpacker.unpack("=xx2x4x8xi12x")
         self.data = xcffib.List(unpacker, "B", self.length * 4)
         self.bufsize = unpacker.offset - base
 
@@ -1586,7 +1586,7 @@ class GenQueriesARBReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x24x")
+        unpacker.unpack("=xx2x4x24x")
         self.data = xcffib.List(unpacker, "I", self.length)
         self.bufsize = unpacker.offset - base
 
@@ -1603,7 +1603,7 @@ class IsQueryARBReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.ret_val,) = unpacker.unpack("xx2x4xI")
+        (self.ret_val,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -1619,7 +1619,7 @@ class GetQueryivARBReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1636,7 +1636,7 @@ class GetQueryObjectivARBReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xIi12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xIi12x")
         self.data = xcffib.List(unpacker, "i", self.n)
         self.bufsize = unpacker.offset - base
 
@@ -1653,7 +1653,7 @@ class GetQueryObjectuivARBReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xII12x")
+        self.n, self.datum = unpacker.unpack("=xx2x4x4xII12x")
         self.data = xcffib.List(unpacker, "I", self.n)
         self.bufsize = unpacker.offset - base
 
